Forums - Mtbr.com
Description: Mountain bike discussion and forum
Keywords: mountain bike reviews discussion forum

- Register
- Remember Me?

1. 1. # Forums - Mtbr.com Welcome to the Forums - Mtbr.com. ## Classic Mountain Bike Forums Threads / Posts Last Post ## Passion (137 Viewing) Share riding experiences. #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 24,959 Posts: 463,498 #### Last Post: Man, I love my vintage... by XDEADGOATX 13 Minutes Ago ## 27.5 - 650b (245 Viewing) 27.5 wheel size Sponsored by ProBikeSupply.com #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,102 Posts: 88,980 #### Last Post: Beginner: Deciding on a 27.5... by drivera 42 Minutes Ago ## 29er Bikes (465 Viewing) Bikes and Frames only! Sponsored by Niner Bikes #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 49,114 Posts: 773,466 #### Last Post: The Official Switchback... by DeeZee 1 Minute Ago ## 29er Components (150 Viewing) 29er Wheels, Tires, Forks, etc. #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,575 Posts: 62,736 #### Last Post: Rims Upgrade by wrinkledink 17 Minutes Ago ## All Mountain (253 Viewing) More than XC, less than FR/DH. #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 14,619 Posts: 252,954 #### Last Post: Saint pedals. by Terranaut 30 Minutes Ago ## Apparel and Protection (101 Viewing) Sponsored by RockGardn #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 7,110 Posts: 84,427 #### Last Post: Sunglasses NOT Polarized? by OldManBike 1 Hour Ago ## Beer Forum (33 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,700 Posts: 50,547 #### Last Post: Any one have any experience... by kjlued 19 Minutes Ago ## Beginner's Corner (266 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 24,607 Posts: 308,771 #### Last Post: WD-40 chain cleaner?? by NateHawk 27 Minutes Ago ## Bike and Frame discussion (88 Viewing) Sponsored by Go-Ride.com #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 16,400 Posts: 120,688 #### Last Post: Switched to Heavier Tires,... by TeeKay 2 Hours Ago ## Bikepacking and Bike Expedition (38 Viewing) Bike camping, touring, adventure #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,043 Posts: 13,124 #### Last Post: thx... by eredinger 6 Hours Ago ## Brake Time (183 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 22,317 Posts: 168,289 #### Last Post: Avid Elixir 9 Lever hard... by Wagon650B 4 Hours Ago ## Car & Biker (105 Viewing) Bike racks and Bike transportation vehicles Sponsored by CracksAndRacks.com #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,898 Posts: 57,286 #### Last Post: Protecting bikes while... by roscoe03 48 Minutes Ago ## Cargo Bikes (3 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 451 Posts: 6,750 #### Last Post: xtraycle edgerunner w/ bionx... by NordicNorm 4 Days Ago ## Clydesdales/Tall Riders (26 Viewing) heavy duty bikes/parts/discussions & big bikes for heavy and/or tall riders Sponsored by Zinn Cycles #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 5,406 Posts: 69,062 #### Last Post: CX Ray spokes for 240lb rider? by Alias530 2 Hours Ago ## Commuting (61 Viewing) Sponsored by NiteRider & Dinotte #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,397 Posts: 69,966 #### Last Post: How was your commute today? by NDD 24 Minutes Ago ## Cyclocross (61 Viewing) from a mountain biker's perpective #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,198 Posts: 14,466 #### Last Post: Ordering rims, will this work? by ms6073 7 Hours Ago ## Downhill - Freeride (163 Viewing) Sponsored by Go-Ride.com #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 48,034 Posts: 719,882 #### Last Post: New to me DH bike. by retrofred 6 Minutes Ago ## Drivetrain - shifters, derailleurs, cranks (251 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 27,121 Posts: 185,265 #### Last Post: Bottom bracket creaking... by bigchillcar 10 Minutes Ago ## Endurance XC Racing (29 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,910 Posts: 79,701 #### Last Post: You either want to or you... by AndySTi 2 Hours Ago ## Enduro Racing (5 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 296 Posts: 3,032 #### Last Post: Trying to lose weight..input... by targnik 13 Hours Ago ## Families and Riding with Kids (87 Viewing) biking with kids/children #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,752 Posts: 19,552 #### Last Post: Motivating Your Kids by griffter18 1 Minute Ago ## Fat Bikes (709 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 9,288 Posts: 194,531 #### Last Post: Rocky Mountain Blizzard Fat... by Aceldama 1 Minute Ago ## Frame Building (78 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,749 Posts: 48,807 #### Last Post: Measurement weapon of choice? by afwalker 6 Minutes Ago ## General Discussion (396 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 43,824 Posts: 622,820 #### Last Post: Why is everyone so obsessed... by dlxah 3 Minutes Ago ## GPS, HRM and Bike Computer (48 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,341 Posts: 26,763 #### Last Post: Garmin 1000 Edge by NateHawk 5 Hours Ago ## Internal Gear Hubs (31 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,017 Posts: 10,583 #### Last Post: Bolt On Mid-mount Internal... by Drew Diller 16 Hours Ago ## Lights and Night Riding (132 Viewing) Sponsored by Cateye & Dinotte Lighting & Lupine & MagicShine & Mtigersports & Xeccon Lights #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,722 Posts: 47,142 #### Last Post: charging the batteries... by DennisF 38 Minutes Ago ## Lights DIY - Do It Yourself (69 Viewing) Sponsored by Dinotte Lighting & Lupine & MagicShine & Mtigersports & Xeccon Lights #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,293 Posts: 80,567 #### Last Post: USB Port 1800lm CREE XML-T6... by bbsantic 4 Hours Ago ## Nutrition and Hydration (10 Viewing) Sponsored by Tailwind Nutrition #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 489 Posts: 8,584 #### Last Post: Leg muscle fatigue by jarwes 1 Day Ago ## NICA - High School - Collegiate Racing brought to you by NICA at http://www.nationalmtb.org/ #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 286 Posts: 2,495 #### Last Post: HS Teams and trail advocacy,... by atayl0r 2 Weeks Ago ## Off Camber (off topic) (76 Viewing) Off topic general discussion (no politics or religion) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,321 Posts: 230,145 #### Last Post: Off Camber Coffee Shop: Now... by Mookie 20 Minutes Ago ## Photography for mountain bikers (4 Viewing) discuss techniques, gear, tips & more #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 317 Posts: 6,393 #### Last Post: Post a picture or two of your... by whitecoyote 17 Hours Ago ## Rider Down, injuries and recovery (56 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,112 Posts: 21,531 #### Last Post: Heart Issue? by bakerjw 5 Hours Ago ## Sea Otter Classic Racing, Camping, Parties, Expo, Product Highlights. #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 482 Posts: 4,410 #### Last Post: Tandem Pics by DHMASTER 4 Weeks Ago ## Shocks and Suspension (335 Viewing) Sponsored by Risse Racing #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 41,440 Posts: 271,966 #### Last Post: Lowering Pike Dual Air from... by Vrexzify 2 Minutes Ago ## Singlespeed (154 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 25,813 Posts: 322,245 #### Last Post: Crawling climbs on a 29er by So Cal RX 2 Hours Ago ## Tandem Mountain Bikes (6 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 752 Posts: 8,555 #### Last Post: Anyone have a new Cannondale... by sisu 11 Hours Ago ## Tooltime (67 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,719 Posts: 37,776 #### Last Post: Powder Coating Old Park... by gmats 3 Hours Ago ## Trail Building and Advocacy (39 Viewing) Sponsored by: IMBA and Professional TrailBuilders Association #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,030 Posts: 23,350 #### Last Post: Should E-bikes be permitted... by challybert 16 Minutes Ago ## Urban/DJ/Park (24 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,819 Posts: 87,367 #### Last Post: New member/bike and some ... by BikeAdvocate 4 Days Ago ## Vacations & Destinations (1 Viewing) biking trips, tours, and travel related biking #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 745 Posts: 4,512 #### Last Post: Akureyri, Iceland riding... by nauc 4 Days Ago ## Videos and POV Cameras (45 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,117 Posts: 24,534 #### Last Post: New entry level go pro by tk1971 4 Hours Ago ## Vintage, Retro, Classic (173 Viewing) Classic bikes and bike restoration forum #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 14,598 Posts: 215,961 #### Last Post: The single consolidated... by tk1971 7 Minutes Ago ## Weight Weenies (99 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 11,654 Posts: 147,768 #### Last Post: Lightweight brakes? by broadwayline 3 Hours Ago ## Wheels and Tires (297 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 33,979 Posts: 246,810 #### Last Post: Does the hub I'm looking for... by heartland 2 Minutes Ago ## Where are the Best Deals? (61 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 9,793 Posts: 68,493 #### Last Post: 20% off on everything from... by Buzz 1 Hour Ago ## Women's Lounge (19 Viewing) Female specific forum. #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,683 Posts: 56,221 #### Last Post: Five (Better) Reasons to Date... by OldManBike 1 Hour Ago ## XC Racing and Training (83 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 9,744 Posts: 132,643 #### Last Post: leg strength (presses,... by scottz123 2 Hours Ago ## Regional Bike Trails and Rides Forums Threads / Posts Last Post Discuss trails and trail conditions. Meet riders from your area. View race and event schedule. Post group rides. ## Alaska (7 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,983 Posts: 21,362 #### Last Post: Group Rides, Thursday Night? by Jayem 17 Hours Ago ## Arizona (90 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 20,029 Posts: 325,747 #### Last Post: Sedona MTB Festival Info by Dambala 1 Hour Ago ## California - Norcal (190 Viewing) Sponsored by Cog Wild Mtn Bike Tours #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 29,800 Posts: 481,287 #### Last Post: Should E-bikes be permitted... by Buzzaro 5 Minutes Ago ## California - Socal (53 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 10,131 Posts: 108,853 #### Last Post: Mission Trails access under... by random walk 1 Hour Ago ## Colorado - Front Range (82 Viewing) Boulder, Denver, Jeffco, Summit County and Winter Park #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 20,983 Posts: 301,481 #### Last Post: OT: What's your favorite Beer... by LittleBitey 1 Hour Ago ## Colorado - Western Slope (6 Viewing) Crested Butte, Gunnison, Montrose, Durango, Telluride, Grand Junction, and Fruita #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,059 Posts: 26,266 #### Last Post: Hartman Rocks by tomcat32 6 Hours Ago ## Connecticut, Rhode Island (1 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,581 Posts: 9,647 #### Last Post: New Bugger Around by thefriar 1 Day Ago ## Great Plains - OK, KS, NE, SD, ND (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,940 Posts: 18,311 #### Last Post: Black hills mountain biking... by JUNGLEKID5 22 Hours Ago ## Hawaii (1 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 645 Posts: 5,192 #### Last Post: Big Island Mtn Biking by gmats 2 Weeks Ago ## Idaho, Montana, Wyoming (7 Viewing) Sponsored by Bike Helena #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 5,681 Posts: 51,401 #### Last Post: Curt Gowdy Conditions by GnarBrahWyo 3 Days Ago ## Massachusetts (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,604 Posts: 19,466 #### Last Post: Jiminy Peak Riding by screamingbunny 21 Hours Ago ## Michigan #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 820 Posts: 4,646 #### Last Post: Groomed Trails by palo92 17 Hours Ago ## Midwest - IL, IN, OH, KY, IA, MO (2 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,690 Posts: 10,860 #### Last Post: Trails around Des Moines, IA by Iowagriz 1 Day Ago ## Minnesota, Wisconsin (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,929 Posts: 13,337 #### Last Post: WI Groomed Fat Trails by slooowfoot 2 Hours Ago ## Midsouth - LA, MS, AR (7 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 778 Posts: 5,562 #### Last Post: Pascagoula MS trails by OldTiGuy 4 Weeks Ago ## Nevada (8 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,418 Posts: 26,526 #### Last Post: Need a tour guide! by Thorin_2 1 Hour Ago ## New Jersey (3 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,431 Posts: 28,121 #### Last Post: Gearing for single speed... by huffster 3 Days Ago ## New Mexico (12 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,096 Posts: 49,432 #### Last Post: Vid: The Whoops - a different... by s0ul_chicken 23 Hours Ago ## New York #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,694 Posts: 17,843 #### Last Post: Graham Hills, Pleasantville,... by TORQUE-29er 2 Days Ago ## North & South Carolina (20 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 7,004 Posts: 74,367 #### Last Post: Help prevent rampant logging... by Woodman 3 Minutes Ago ## Oregon (25 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,405 Posts: 64,918 #### Last Post: Changes coming for Scappose -... by mtnbkr77 5 Hours Ago ## Pennsylvania (14 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 5,885 Posts: 60,826 #### Last Post: Ride da Moon by Z-wave 42 Minutes Ago ## Southeast - GA, TN, AL, FL (8 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 5,284 Posts: 47,939 #### Last Post: Thinking of going to... by OffCamber 14 Minutes Ago ## Texas (7 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,152 Posts: 22,415 #### Last Post: What's the riding like in... by ForrestNinja 19 Hours Ago ## Utah (19 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,132 Posts: 35,997 #### Last Post: Potential move to SLC or Park... by dgw2jr 18 Minutes Ago ## Vermont, New Hampshire, Maine (8 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,902 Posts: 39,926 #### Last Post: Central NH Fat Bikers by Katz 8 Hours Ago ## Virginia, WV, Maryland, DC, Delaware (11 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,735 Posts: 43,048 #### Last Post: White Park, Black Friday by MadPainterGrafx 2 Hours Ago ## Washington (34 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,752 Posts: 66,231 #### Last Post: Join the Winter Work Party on... by DRSpalding 11 Minutes Ago ## Western Canada (9 Viewing) Yukon, NW, BC, Alberta, Saskatchewan, Manitoba #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,542 Posts: 14,971 #### Last Post: Edmonton Fall/Winter 2014/2015 by Fejjo 6 Hours Ago ## Eastern Canada (40 Viewing) Ontario, Quebec, Nova Scotia, Newfoundland, New Brunswick #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,288 Posts: 107,564 #### Last Post: We start flagging early... by singlesprocket 1 Hour Ago ## Mexico (23 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,659 Posts: 25,403 #### Last Post: Consejos para garantia,... by armamora1 6 Hours Ago ## Australia, New Zealand (6 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,547 Posts: 24,525 #### Last Post: Auckland Aiport to Rotorua by tahic 1 Day Ago ## Europe (3 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 768 Posts: 5,113 #### Last Post: Stolen : On One Whippet,... by Lazy Andy 14 Hours Ago ## Asia (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 229 Posts: 1,816 #### Last Post: Indonesia....? by cactolith 1 Week Ago ## Philippines The place for Filipino Mountain Bikers #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 87 Posts: 1,294 #### Last Post: First National Bike Day... by discombobulated_conundrum 1 Week Ago ## Other Areas South America, Carribean, South Africa... #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 277 Posts: 1,199 #### Last Post: MTB in Bogota, Colombia by Carton 1 Week Ago ## Mountain Bike Manufacturer Forums Threads / Posts Last Post Owners unite!! Let's get together and exchange experiences. ## Airborne (32 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 889 Posts: 15,217 #### Last Post: I guess this is a good time... by Black Pearl 36 Minutes Ago ## Banshee Bikes (19 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,351 Posts: 30,438 #### Last Post: 2014 Spitfire V2 27.5... by nvphatty 4 Hours Ago ## BMC (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 232 Posts: 2,372 #### Last Post: BMC Fourstroke 03 by Sorcerer 3 Days Ago ## Canfield (12 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 538 Posts: 9,851 #### Last Post: Man, I love these frames by kickhorse 3 Minutes Ago ## Cannondale (136 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 13,954 Posts: 137,151 #### Last Post: 1x10 question for newb!! by jdinsj 2 Hours Ago ## Commencal (2 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 272 Posts: 2,135 #### Last Post: New US Distro? by jej 50 Minutes Ago ## Diamondback (15 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,199 Posts: 10,651 #### Last Post: Your Recoil Pictures, Lets... by RSDSav 38 Minutes Ago ## Ellsworth (2 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 3,007 Posts: 34,231 #### Last Post: Roll Call - show us your... by 1Troutbum 2 Days Ago ## Felt (2 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 300 Posts: 2,498 #### Last Post: Ask FELT by penzzz 9 Hours Ago ## Foes (3 Viewing) Foes Bicycles #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 632 Posts: 6,043 #### Last Post: lets see your foes!! by Jon Richard 5 Days Ago ## Fuji (2 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 215 Posts: 1,549 #### Last Post: Why no Fuji love? by alvarezmtbgt 6 Days Ago ## Gary Fisher (8 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,371 Posts: 19,663 #### Last Post: What every Gary Fisher owner... by roxtar 3 Days Ago ## Giant (85 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 8,215 Posts: 83,916 #### Last Post: TRANCE - The Official thread,... by zadamxtr 14 Minutes Ago ## GT (30 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,750 Posts: 25,181 #### Last Post: Weights of GT 2013 Karakoram... by matadorCE 3 Hours Ago ## Haro (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,589 Posts: 12,345 #### Last Post: Extreme X2 (?) seeking advice by Abagrizzli 10-13-2014 ## Ibis (117 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 5,620 Posts: 82,583 #### Last Post: Unbelievable deal on an Mojo... by ebry74 9 Minutes Ago ## Intense (25 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,978 Posts: 77,210 #### Last Post: Random Intense Pic by JDubKC 1 Hour Ago ## Iron Horse (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,291 Posts: 38,885 #### Last Post: 04-06 Ironnhorse Warrior Comp... by Hardtale 2 Weeks Ago ## Jamis (6 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,551 Posts: 11,281 #### Last Post: Jamis Dakar XCR 29er: anybody... by ForrestNinja 19 Hours Ago ## KHS (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 164 Posts: 1,510 #### Last Post: sad, and yet not so sad by B@dKarma 3 Days Ago ## Kona (46 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,223 Posts: 33,854 #### Last Post: Kona Process 153 2014 by kimbers 1 Hour Ago ## Knolly (20 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,722 Posts: 48,959 #### Last Post: So who's all ordered a new... by RyeBokeh 18 Hours Ago ## Litespeed #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 326 Posts: 1,991 #### Last Post: Show Us Your... by hkbugs 07-02-2014 ## Lynskey (1 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 28 Posts: 222 #### Last Post: Ti fatty by twklei 2 Weeks Ago ## Marin (6 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 903 Posts: 6,465 #### Last Post: New Ride! by Smurphey 2 Hours Ago ## Maverick (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,173 Posts: 11,390 #### Last Post: what forks for my Durance by banks 1 Day Ago ## Mongoose-Schwinn (6 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 592 Posts: 5,887 #### Last Post: Mongoose Vinson by phillyhorse 2 Days Ago ## Moots (2 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 473 Posts: 3,486 #### Last Post: Mootseesess Make Over. Anyone... by Johnny Chicken Bones 1 Day Ago ## Motobecane (13 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,759 Posts: 15,918 #### Last Post: Gravity Deadeye Vs Deadeye... by kjlued 12 Minutes Ago ## Mountain Cycle (4 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 551 Posts: 6,711 #### Last Post: Mountain Cycle frame circa... by Mountain Cycle Shawn 1 Day Ago ## Nicolai (10 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,412 Posts: 29,797 #### Last Post: Helius AC Pinion build by dejacky 20 Hours Ago ## Niner Bikes (42 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,748 Posts: 54,533 #### Last Post: Rip 9 frame size advice. by muzzanic 1 Hour Ago ## Norco (6 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 270 Posts: 2,278 #### Last Post: 2015 Norco Sight by bryan_d 3 Hours Ago ## On One (22 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 518 Posts: 6,580 #### Last Post: Whoa! Carbon 456 Evo by MMcG 2 Days Ago ## Pivot Cycles (28 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,007 Posts: 24,424 #### Last Post: Post your Pivots here! by PATTON 7 Hours Ago ## Redline (3 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 501 Posts: 3,743 #### Last Post: Recent upgrades to your... by A1an 3 Weeks Ago ## Ritchey Design (9 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 668 Posts: 5,589 #### Last Post: Ritchey Rep here to answer... by ritchey_dave 1 Day Ago ## Rocky Mountain (17 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,966 Posts: 28,749 #### Last Post: CTD Dual remote lever dumped... by eric 15 Hours Ago ## Salsa (53 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,490 Posts: 29,125 #### Last Post: Salsa Spearfish sizing? by giant_kyle 6 Minutes Ago ## Santa Cruz (157 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 14,159 Posts: 163,845 #### Last Post: Tallboy LT and LTc Owners... by yeahdog31 2 Hours Ago ## Scott Sports (50 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,016 Posts: 8,466 #### Last Post: Sparks...lets see em by zephxiii 6 Days Ago ## Sette (7 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 465 Posts: 6,740 #### Last Post: Sette Reken build by aarontriton 10-11-2014 ## Shimano (17 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 1,142 Posts: 7,756 #### Last Post: SRAM 10-42 cassette + Shimano... by westin 5 Days Ago ## Specialized (255 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 18,769 Posts: 194,614 #### Last Post: Official Specialized Camber... by sml-2727 4 Minutes Ago ## SRAM (20 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,294 Posts: 13,998 #### Last Post: New, DOA X0 Trigger Shifter... by ylg 1 Day Ago ## Surly (70 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,268 Posts: 34,840 #### Last Post: Karate Monkey Sizing by mack_turtle 23 Minutes Ago ## Titus (11 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,456 Posts: 87,372 #### Last Post: Monarch RT3 by Tim22 1 Day Ago ## Trek (107 Viewing) and Bontrager #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,873 Posts: 61,250 #### Last Post: 2015 Remedy 9 650B by MadPainterGrafx 2 Hours Ago ## Transition Bikes (16 Viewing) Sponsored by The Dropnzone #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,122 Posts: 27,068 #### Last Post: Anyone rode the Patrol ??? by AdrianoMTB 2 Hours Ago ## Turner (49 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 20,939 Posts: 324,345 #### Last Post: Czar with a Cane Creek DB... by consolidated 7 Minutes Ago ## Ventana (6 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 4,057 Posts: 48,436 #### Last Post: 2014 Picture Thread by El Salt 1 Hour Ago ## Yeti (82 Viewing) #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 6,616 Posts: 76,250 #### Last Post: Yeti SB-66 Build thread by mns 55 Minutes Ago ## Custom Builders & Other Manufacturers (13 Viewing) Lapierre, Liteville, Orbea, Raleigh, Tomac, Vassago, Voodoo, Retrotec, Eriksen, Black Sheep, Soma, Sycip, Funk, IF and others #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,310 Posts: 24,006 #### Last Post: Thee Official Soma Thread by hydrogeek 1 Day Ago ## Custom DH/FR/Urban Builders (2 Viewing) Azonic, Bicycle Fab, Black Market, Evil, Morewood, Morpheus, Sinister and others #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 237 Posts: 2,848 #### Last Post: Hole on welding! Should I... by Paris Galanis 07-17-2014 ## Canadian Bikes (3 Viewing) Devinci, Chromag, Cove, Brodie, Dekerf, Oryx and others #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 787 Posts: 6,100 #### Last Post: 2015 Devinci Wilson 650b by JNG 3 Days Ago ## Info Threads / Posts Last Post ## Site Feedback/Issues (3 Viewing) Give feedback, ask questions, make suggestions, etc. HAVING TROUBLE REGISTERING OR HANDLE TAKEN?? Post here and we will help you! #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 2,758 Posts: 16,434 #### Last Post: Change MTBR.com User ID? by Job1 4 Days Ago ## The ReCycle Bin (4 Viewing) #### Forum Actions: #### Forum Statistics: Threads: 1,190 Posts: 41,675 #### Last Post: America is exceptional by net wurker 09-15-2014 ## test forum #### Forum Actions: View this forum's RSS feed #### Forum Statistics: Threads: 274 Posts: 57,721 #### Last Post: filter test by aerius 3 Days Ago ## Featured Member Photos
      Altai Hok skis
      by Mikhs · · · Member Galleries |
      stragggler
      by mrgould · · · Surly Straggler |
      straggler
      by mrgould · · · Surly Straggler |
      Clinton River
      by sleepyguy1001 · · · Member Galleries
1. 1. ## Featured Member Ads
      2014 Kona Process 134 SE Demo bike
      by PeoplesBicycle · · · Full Suspension Bike |
      2014 Santa Cruz Bronson Carbon Demo bike
      by PeoplesBicycle · · · Full Suspension Bike |
      2014 Santa Cruz Tallboy Carbon C Demo bike
      by PeoplesBicycle · · · Full Suspension Bike |
      2014 Santa Cruz 5010 Carbon Demo bike
      by PeoplesBicycle · · · Full Suspension Bike
Mark Forums Read | View Forum Leaders ## What's Going On? ### Currently Active Users There are currently 24263 users online. 2192 members and 22071 guests Most users ever online was 39,135, 07-06-2011 at 02:29 PM. ### Today's Birthdays Crankypants, Nor'Easter, chad2102, n62bm (67), SprungShoulders (47), fsr1 (47), jhemp (46), gtshouse (45), majorclyde (44), Wilbur (44), RRIII (44), ocsdpig2398 (44), bikehelmet (43), trexnfx (42), 2HARSH (42), Wait4Me (41), subarizona (40), ulese (40), JustinCantalupo (40), tiagradura (39), sarahbelle (39), The_Real_Cyclesmith (38), TN29'er (38), Duck_Butter (38), Wally Sheata (38), mkrause33 (37), biketrials247 (37), jabberwocky (37), cdad_martinez (37), firem2 (35), richz34 (34), XC_Miles (33), biohazard (33), intro123 (33), SuPrBuGmAn (33), therealjurgens (28), LavaPunk (27) ### Forums - Mtbr.com Statistics Threads 904,648 Posts 11,316,004 Members 388,495 Active Members 17,597 Welcome to our newest member, Dirt-Dude! ### Icon Legend Contains unread forum posts Contains no unread forum posts Forum is a category Forum is a Link